@@ -4,12 +4,10 @@ from logging import getLogger
 from typing import Optional, Tuple
 
 from scrapli.driver import AsyncScrape, Scrape
+from scrapli.factory import AsyncScrapli, Scrapli
 
-__version__ = "2020.07.04"
-__all__ = (
-    "AsyncScrape",
-    "Scrape",
-)
+__version__ = "2020.08.28"
+__all__ = ("AsyncScrape", "Scrape", "AsyncScrapli", "Scrapli")
 
 
 class DuplicateFilter(logging.Filter):
