@@ -1,9 +1,11 @@
 """scrapli.channel.channel"""
 import re
+import time
 from typing import Any, List, Optional, Tuple
 
 from scrapli.channel.base_channel import ChannelBase
-from scrapli.decorators import operation_timeout
+from scrapli.decorators import OperationTimeout
+from scrapli.exceptions import ScrapliTimeout
 from scrapli.helper import get_prompt_pattern, strip_ansi
 from scrapli.transport.transport import Transport
 
@@ -54,7 +56,7 @@ class Channel(ChannelBase):
         Read until all input has been entered.
 
         Args:
-            channel_input: string to write to channel
+            channel_input: bytes to write to channel
             auto_expand: bool to indicate if a device auto-expands commands, for example juniper
                 devices without `cli complete-on-space` disabled will convert `config` to
                 `configuration` after entering a space character after `config`; because scrapli
@@ -78,9 +80,17 @@ class Channel(ChannelBase):
         if auto_expand is None:
             auto_expand = self.comms_auto_expand
 
+        # squish all channel input words together and cast to lower to make comparison easier
+        processed_channel_input = b"".join(channel_input.lower().split())
+
         while True:
             output += self._read_chunk()
-            if not auto_expand and channel_input in output:
+
+            # replace any backspace chars (particular problem w/ junos), and remove any added spaces
+            # this is just for comparison of the inputs to what was read from channel
+            if not auto_expand and processed_channel_input in b"".join(
+                output.lower().replace(b"\x08", b"").split()
+            ):
                 break
             if auto_expand and self._process_auto_expand(
                 output=output, channel_input=channel_input
@@ -116,7 +126,64 @@ class Channel(ChannelBase):
                 self.logger.info(f"Read: {repr(output)}")
                 return output
 
-    @operation_timeout("timeout_ops", "Timed out determining prompt on device.")
+    def _read_until_prompt_or_time(
+        self,
+        output: bytes = b"",
+        channel_outputs: Optional[List[bytes]] = None,
+        read_duration: Optional[float] = None,
+    ) -> bytes:
+        """
+        Read until expected prompt is seen, outputs are seen, or for duration, whichever comes first
+
+        As transport reading may block, transport timeout is temporarily set to the read_duration
+        and any `ScrapliTimeout` that is raised while reading is ignored.
+
+        Args:
+            output: bytes from previous reads if needed
+            channel_outputs: List of bytes to search for in channel output, if any are seen, return
+                read output
+            read_duration: duration to read from channel for
+
+        Returns:
+            bytes: output read from channel
+
+        Raises:
+            N/A
+
+        """
+        prompt_pattern = get_prompt_pattern(prompt="", class_prompt=self.comms_prompt_pattern)
+
+        if channel_outputs is None:
+            channel_outputs = []
+        if read_duration is None:
+            read_duration = 2.5
+
+        previous_timeout_transport = self.transport.timeout_transport
+        self.transport.timeout_transport = int(read_duration)
+
+        start = time.time()
+        while True:
+            try:
+                output += self._read_chunk()
+            except ScrapliTimeout:
+                pass
+
+            if self.comms_ansi:
+                output = strip_ansi(output=output)
+
+            if (time.time() - start) > read_duration:
+                break
+            if any([channel_output in output for channel_output in channel_outputs]):
+                break
+            if re.search(pattern=prompt_pattern, string=output):
+                break
+
+        self.transport.timeout_transport = previous_timeout_transport
+
+        self.logger.info(f"Read: {repr(output)}")
+        return output
+
+    @OperationTimeout(attribute="timeout_ops", message="Timed out determining prompt on device.")
     def get_prompt(self) -> str:
         """
         Get current channel prompt
@@ -132,7 +199,6 @@ class Channel(ChannelBase):
 
         """
         prompt_pattern = get_prompt_pattern(prompt="", class_prompt=self.comms_prompt_pattern)
-        self.transport.set_timeout(timeout=10)
         self._send_return()
         output = b""
         while True:
@@ -141,17 +207,22 @@ class Channel(ChannelBase):
                 output = strip_ansi(output=output)
             channel_match = re.search(pattern=prompt_pattern, string=output)
             if channel_match:
-                self.transport.set_timeout()
                 current_prompt = channel_match.group(0)
                 return current_prompt.decode().strip()
 
-    def send_input(self, channel_input: str, strip_prompt: bool = True) -> Tuple[bytes, bytes]:
+    @OperationTimeout(attribute="timeout_ops", message="Timed out sending input to device.")
+    def send_input(
+        self, channel_input: str, strip_prompt: bool = True, eager: bool = False
+    ) -> Tuple[bytes, bytes]:
         """
         Primary entry point to send data to devices in shell mode; accept input and returns result
 
         Args:
             channel_input: string input to send to channel
             strip_prompt: strip prompt or not, defaults to True (yes, strip the prompt)
+            eager: eager mode reads and returns the `_read_until_input` value, but does not attempt
+                to read to the prompt pattern -- this should not be used manually! (only used by
+                `send_configs` with the eager flag set)
 
         Returns:
             raw_result: output read from the channel with no whitespace trimming/cleaning
@@ -162,19 +233,40 @@ class Channel(ChannelBase):
 
         """
         self._pre_send_input(channel_input=channel_input)
-        raw_result, processed_result = self._send_input(
-            channel_input=channel_input, strip_prompt=strip_prompt
-        )
-        return raw_result, processed_result
 
-    @operation_timeout("timeout_ops", "Timed out sending input to device.")
-    def _send_input(self, channel_input: str, strip_prompt: bool) -> Tuple[bytes, bytes]:
+        bytes_channel_input = channel_input.encode()
+
+        with self.transport.session_lock:
+            self.logger.info(
+                f"Attempting to send input: {channel_input}; strip_prompt: {strip_prompt}"
+            )
+            self.transport.write(channel_input=channel_input)
+            self.logger.debug(f"Write: {repr(channel_input)}")
+            output = self._read_until_input(channel_input=bytes_channel_input)
+            self._send_return()
+            if not eager:
+                output = self._read_until_prompt()
+        processed_output = self._restructure_output(output=output, strip_prompt=strip_prompt)
+
+        return output, processed_output
+
+    @OperationTimeout(attribute="timeout_ops", message="Timed out sending and reading to device.")
+    def send_input_and_read(
+        self,
+        channel_input: str,
+        strip_prompt: bool = True,
+        expected_outputs: Optional[List[str]] = None,
+        read_duration: Optional[float] = None,
+    ) -> Tuple[bytes, bytes]:
         """
-        Send input to device and return results
+        Send a command and read until expected prompt is seen, outputs are seen, or for duration
 
         Args:
-            channel_input: string input to write to channel
-            strip_prompt: bool True/False for whether or not to strip prompt
+            channel_input: string input to send to channel
+            strip_prompt: strip prompt or not, defaults to True (yes, strip the prompt)
+            expected_outputs: list of strings to look for in output; if any of these are seen,
+                return output read up till that read
+            read_duration: float duration to read for
 
         Returns:
             raw_result: output read from the channel with no whitespace trimming/cleaning
@@ -184,22 +276,27 @@ class Channel(ChannelBase):
             N/A
 
         """
+        self._pre_send_input(channel_input=channel_input)
+
         bytes_channel_input = channel_input.encode()
-        self.transport.session_lock.acquire()
-        self.logger.info(f"Attempting to send input: {channel_input}; strip_prompt: {strip_prompt}")
-        self.transport.write(channel_input=channel_input)
-        self.logger.debug(f"Write: {repr(channel_input)}")
-        self._read_until_input(channel_input=bytes_channel_input)
-        self._send_return()
-        output = self._read_until_prompt()
-        self.transport.session_lock.release()
+        bytes_channel_outputs = [
+            channel_output.encode() for channel_output in expected_outputs or []
+        ]
+
+        with self.transport.session_lock:
+            self.transport.write(channel_input=channel_input)
+            self.logger.debug(f"Write: {repr(channel_input)}")
+            self._read_until_input(channel_input=bytes_channel_input)
+            self._send_return()
+            output = self._read_until_prompt_or_time(
+                channel_outputs=bytes_channel_outputs, read_duration=read_duration
+            )
         processed_output = self._restructure_output(output=output, strip_prompt=strip_prompt)
-        # lstrip the return character out of the final result before storing, also remove any extra
-        # whitespace to the right if any
-        processed_output = processed_output.lstrip(self.comms_return_char.encode()).rstrip()
         return output, processed_output
 
-    @operation_timeout("timeout_ops", "Timed out sending interactive input to device.")
+    @OperationTimeout(
+        attribute="timeout_ops", message="Timed out sending interactive input to device."
+    )
     def send_inputs_interact(
         self, interact_events: List[Tuple[str, str, Optional[bool]]]
     ) -> Tuple[bytes, bytes]:
@@ -265,29 +362,28 @@ class Channel(ChannelBase):
         """
         self._pre_send_inputs_interact(interact_events=interact_events)
 
-        self.transport.session_lock.acquire()
         output = b""
-        for interact_event in interact_events:
-            channel_input = interact_event[0]
-            bytes_channel_input = channel_input.encode()
-            channel_response = interact_event[1]
-            try:
-                hidden_input = interact_event[2]
-            except IndexError:
-                hidden_input = False
-            self.logger.info(
-                f"Attempting to send input interact: {channel_input}; "
-                f"\texpecting: {channel_response};"
-                f"\thidden_input: {hidden_input}"
-            )
-            self.transport.write(channel_input=channel_input)
-            self.logger.debug(f"Write: {repr(channel_input)}")
-            if not channel_response or hidden_input is True:
-                self._send_return()
-            else:
-                output += self._read_until_input(channel_input=bytes_channel_input)
-                self._send_return()
-            output += self._read_until_prompt(prompt=channel_response)
-        # wait to release lock until after "interact" session is complete
-        self.transport.session_lock.release()
+        with self.transport.session_lock:
+            for interact_event in interact_events:
+                channel_input = interact_event[0]
+                bytes_channel_input = channel_input.encode()
+                channel_response = interact_event[1]
+                try:
+                    hidden_input = interact_event[2]
+                except IndexError:
+                    hidden_input = False
+                self.logger.info(
+                    f"Attempting to send input interact: {channel_input}; "
+                    f"\texpecting: {channel_response};"
+                    f"\thidden_input: {hidden_input}"
+                )
+                self.transport.write(channel_input=channel_input)
+                self.logger.debug(f"Write: {repr(channel_input)}")
+                if not channel_response or hidden_input is True:
+                    self._send_return()
+                else:
+                    output += self._read_until_input(channel_input=bytes_channel_input)
+                    self._send_return()
+                output += self._read_until_prompt(prompt=channel_response)
+
         return self._post_send_inputs_interact(output=output)
