@@ -2,7 +2,7 @@
 import os
 import re
 import sys
-from logging import getLogger
+from logging import Logger, getLogger
 from pathlib import Path
 from typing import Any, Callable, Dict, Optional, Tuple, Union
 
@@ -36,6 +36,7 @@ TRANSPORT_BASE_ARGS = (
     "timeout_transport",
     "timeout_exit",
 )
+ASYNCIO_TRANSPORTS = ("asyncssh",)
 
 
 class ScrapeBase:
@@ -51,7 +52,7 @@ class ScrapeBase:
         auth_bypass: bool = False,
         timeout_socket: int = 5,
         timeout_transport: int = 10,
-        timeout_ops: int = 30,
+        timeout_ops: float = 30,
         timeout_exit: bool = True,
         keepalive: bool = False,
         keepalive_interval: int = 30,
@@ -155,7 +156,7 @@ class ScrapeBase:
         self._initialization_args: Dict[str, Any] = {}
 
         self._setup_host(host=host, port=port)
-        self.logger = getLogger(f"scrapli.driver-{self._host}")
+        self.logger: Logger = getLogger(f"scrapli.driver-{self._host}")
 
         self._setup_auth(
             auth_username=auth_username,
@@ -171,6 +172,7 @@ class ScrapeBase:
             timeout_ops=timeout_ops,
             timeout_exit=timeout_exit,
         )
+        self._timeout_ops: float = self._initialization_args["timeout_ops"]
         self._setup_keepalive(
             keepalive=keepalive,
             keepalive_type=keepalive_type,
@@ -348,7 +350,11 @@ class ScrapeBase:
             self._initialization_args["auth_private_key"] = auth_private_key
 
     def _setup_timeouts(
-        self, timeout_socket: int, timeout_transport: int, timeout_ops: int, timeout_exit: bool
+        self,
+        timeout_socket: int,
+        timeout_transport: int,
+        timeout_ops: float,
+        timeout_exit: bool,
     ) -> None:
         """
         Parse and setup timeout attributes
@@ -371,7 +377,7 @@ class ScrapeBase:
 
         self._initialization_args["timeout_socket"] = int(timeout_socket)
         self._initialization_args["timeout_transport"] = int(timeout_transport)
-        self._initialization_args["timeout_ops"] = int(timeout_ops)
+        self._initialization_args["timeout_ops"] = float(timeout_ops)
         self._initialization_args["timeout_exit"] = timeout_exit
 
     def _setup_keepalive(
