@@ -21,7 +21,7 @@ PRIVS = {
             deescalate="disable",
             escalate="enable",
             escalate_auth=True,
-            escalate_prompt=r"^[pP]assword:\s?$",
+            escalate_prompt=r"^(?:enable\s){0,1}password:\s?$",
         )
     ),
     "configuration": (
