@@ -3,7 +3,7 @@ import re
 from select import select
 from typing import Any, Dict, Optional
 
-from scrapli.decorators import operation_timeout, requires_open_session
+from scrapli.decorators import OperationTimeout, requires_open_session
 from scrapli.exceptions import ScrapliAuthenticationFailed
 from scrapli.helper import get_prompt_pattern, strip_ansi
 from scrapli.ssh_config import SSHConfig
@@ -39,7 +39,7 @@ class SystemSSHTransport(Transport):
         auth_bypass: bool = False,
         timeout_socket: int = 5,
         timeout_transport: int = 5,
-        timeout_ops: int = 10,
+        timeout_ops: float = 10,
         timeout_exit: bool = True,
         keepalive: bool = False,
         keepalive_interval: int = 30,
@@ -162,7 +162,7 @@ class SystemSSHTransport(Transport):
         self.auth_strict_key: bool = auth_strict_key
         self.auth_bypass: bool = auth_bypass
 
-        self._timeout_ops: int = timeout_ops
+        self._timeout_ops: float = timeout_ops
         self._comms_prompt_pattern: str = comms_prompt_pattern
         self._comms_return_char: str = comms_return_char
         self._comms_ansi: bool = comms_ansi
@@ -280,7 +280,7 @@ class SystemSSHTransport(Transport):
             msg = f"Timed out connecting to host {self.host}"
         elif b"no route to host" in output.lower():
             msg = f"No route to host {self.host}"
-        elif b"no matching key exchange found" in output.lower():
+        elif b"no matching key exchange" in output.lower():
             msg = f"No matching key exchange found for host {self.host}"
             key_exchange_pattern = re.compile(
                 pattern=rb"their offer: ([a-z0-9\-,]*)", flags=re.M | re.I
@@ -292,7 +292,7 @@ class SystemSSHTransport(Transport):
                     f"No matching key exchange found for host {self.host}, their offer: "
                     f"{offered_key_exchanges}"
                 )
-        elif b"no matching cipher found" in output.lower():
+        elif b"no matching cipher" in output.lower():
             msg = f"No matching cipher found for host {self.host}"
             ciphers_pattern = re.compile(pattern=rb"their offer: ([a-z0-9\-,]*)", flags=re.M | re.I)
             offered_ciphers_match = re.search(pattern=ciphers_pattern, string=output)
@@ -301,6 +301,18 @@ class SystemSSHTransport(Transport):
                 msg = (
                     f"No matching cipher found for host {self.host}, their offer: {offered_ciphers}"
                 )
+        elif b"bad configuration" in output.lower():
+            msg = f"Bad SSH configuration option(s) for host {self.host}"
+            configuration_pattern = re.compile(
+                pattern=rb"bad configuration option: ([a-z0-9\+\=,]*)", flags=re.M | re.I
+            )
+            configuration_issue_match = re.search(pattern=configuration_pattern, string=output)
+            if configuration_issue_match:
+                configuration_issues = configuration_issue_match.group(1).decode()
+                msg = (
+                    f"Bad SSH configuration option(s) for host {self.host}, bad option(s): "
+                    f"{configuration_issues}"
+                )
         elif b"WARNING: UNPROTECTED PRIVATE KEY FILE!" in output:
             msg = (
                 f"Permissions for private key `{self.auth_private_key}` are too open, "
@@ -345,7 +357,7 @@ class SystemSSHTransport(Transport):
         self.logger.debug(f"Authenticated to host {self.host} with password")
         return True
 
-    @operation_timeout("_timeout_ops", "Timed out attempting to authenticate")
+    @OperationTimeout("_timeout_ops", "Timed out attempting to authenticate")
     def _authenticate(self) -> None:
         """
         Private method to check initial authentication when using pty_session
@@ -361,55 +373,51 @@ class SystemSSHTransport(Transport):
                 explicit exception/message
 
         """
-        self.session_lock.acquire()
         output = b""
         prompt_pattern = get_prompt_pattern(prompt="", class_prompt=self._comms_prompt_pattern)
-        while True:
-            try:
-                new_output = self.session.read()
-                output += new_output
-                self.logger.debug(f"Attempting to authenticate. Read: {repr(new_output)}")
-            except EOFError:
+        with self.session_lock:
+            while True:
+                try:
+                    new_output = self.session.read()
+                    output += new_output
+                    self.logger.debug(f"Attempting to authenticate. Read: {repr(new_output)}")
+                except EOFError as exc:
+                    self._ssh_message_handler(output=output)
+                    # if _ssh_message_handler didn't raise any exception, we can raise the standard
+                    # "did you disable strict key message/exception"
+                    msg = (
+                        f"Failed to open connection to host {self.host}. Do you need to disable "
+                        "`auth_strict_key`?"
+                    )
+                    self.logger.critical(msg)
+                    raise ScrapliAuthenticationFailed(msg) from exc
+
+                # even if we dont hit EOF, we may still have hit a message we need to process such
+                # as insecure key permissions
                 self._ssh_message_handler(output=output)
-                # if _ssh_message_handler didn't raise any exception, we can raise the standard --
-                # did you disable strict key message/exception
-                msg = (
-                    f"Failed to open connection to host {self.host}. Do you need to disable "
-                    "`auth_strict_key`?"
-                )
-                self.logger.critical(msg)
-                self.session_lock.release()
-                raise ScrapliAuthenticationFailed(msg)
 
-            # even if we dont hit EOF, we may still have hit a message we need to process such as
-            # insecure key permissions
-            self._ssh_message_handler(output=output)
+                if self._comms_ansi or b"\x1B" in output:
+                    output = strip_ansi(output=output)
+                if b"password" in output.lower():
+                    self.logger.info("Found password prompt, sending password")
+                    self.session.write(self.auth_password.encode())
+                    self.session.write(self._comms_return_char.encode())
+                    break
+                if b"enter passphrase for key" in output.lower():
+                    self.logger.info("Found key passphrase prompt, sending passphrase")
+                    self.session.write(self.auth_private_key_passphrase.encode())
+                    self.session.write(self._comms_return_char.encode())
+                    break
+                channel_match = re.search(pattern=prompt_pattern, string=output)
+                if channel_match:
+                    self.logger.info(
+                        "Found channel prompt, assuming that key based authentication has succeeded"
+                    )
+                    # set _isauthenticated to true, we've already authenticated, don't re-check
+                    self._isauthenticated = True
+                    break
 
-            if self._comms_ansi or b"\x1B" in output:
-                output = strip_ansi(output=output)
-            if b"password" in output.lower():
-                self.logger.info("Found password prompt, sending password")
-                self.session.write(self.auth_password.encode())
-                self.session.write(self._comms_return_char.encode())
-                self.session_lock.release()
-                break
-            if b"enter passphrase for key" in output.lower():
-                self.logger.info("Found key passphrase prompt, sending passphrase")
-                self.session.write(self.auth_private_key_passphrase.encode())
-                self.session.write(self._comms_return_char.encode())
-                self.session_lock.release()
-                break
-            channel_match = re.search(pattern=prompt_pattern, string=output)
-            if channel_match:
-                self.logger.info(
-                    "Found channel prompt, assuming that key based authentication has succeeded"
-                )
-                # set _isauthenticated to true, we've already authenticated, don't need to re-check
-                self._isauthenticated = True
-                self.session_lock.release()
-                break
-
-    @operation_timeout("_timeout_ops", "Timed out determining if session is authenticated")
+    @OperationTimeout("_timeout_ops", "Timed out determining if session is authenticated")
     def _system_isauthenticated(self) -> bool:
         """
         Check if session is authenticated
@@ -428,48 +436,49 @@ class SystemSSHTransport(Transport):
 
         """
         self.logger.debug("Attempting to determine if authentication was successful")
-        self.session_lock.acquire()
-        if self.session.isalive() and not self.session.eof():
-            prompt_pattern = get_prompt_pattern(prompt="", class_prompt=self._comms_prompt_pattern)
-            self.session.write(self._comms_return_char.encode())
-            while True:
-                # almost all of the time we don't need a while loop here, but every once in a while
-                # fd won't be ready which causes a failure without an obvious root cause,
-                # loop/logging to hopefully help with that
-                fd_ready, _, _ = select([self.session.fd], [], [], 0)
-                if self.session.fd in fd_ready:
-                    break
-                self.logger.debug("PTY fd not ready yet...")
-            output = b""
-            while True:
-                new_output = self.session.read()
-                output += new_output
-                self.logger.debug(
-                    f"Attempting to validate authentication. Read: {repr(new_output)}"
+        with self.session_lock:
+            if self.session.isalive() and not self.session.eof():
+                prompt_pattern = get_prompt_pattern(
+                    prompt="", class_prompt=self._comms_prompt_pattern
                 )
-                # we do not need to deal w/ line replacement for the actual output, only for
-                # parsing if a prompt-like thing is at the end of the output
-                output = output.replace(b"\r", b"")
-                # always check to see if we should strip ansi here; if we don't handle this we
-                # may raise auth failures for the wrong reason which would be confusing for
-                # users
-                if self._comms_ansi or b"\x1B" in output:
-                    output = strip_ansi(output=output)
-                channel_match = re.search(pattern=prompt_pattern, string=output)
-                if channel_match:
-                    self._isauthenticated = True
-                    break
-                if b"password:" in output.lower():
-                    # if we see "password" we know auth failed (hopefully in all scenarios!)
-                    self.logger.critical(
-                        "Found `password:` in output, assuming password authentication failed"
-                    )
-                    break
-                if output:
+                self.session.write(self._comms_return_char.encode())
+                while True:
+                    # almost all of the time we don't need a while loop here, but every once in a
+                    # while fd won't be ready which causes a failure without an obvious root cause,
+                    # loop/logging to hopefully help with that
+                    fd_ready, _, _ = select([self.session.fd], [], [], 0)
+                    if self.session.fd in fd_ready:
+                        break
+                    self.logger.debug("PTY fd not ready yet...")
+                output = b""
+                while True:
+                    new_output = self.session.read()
+                    output += new_output
                     self.logger.debug(
-                        f"Cannot determine if authenticated, \n\tRead: {repr(output)}"
+                        f"Attempting to validate authentication. Read: {repr(new_output)}"
                     )
-        self.session_lock.release()
+                    # we do not need to deal w/ line replacement for the actual output, only for
+                    # parsing if a prompt-like thing is at the end of the output
+                    output = output.replace(b"\r", b"")
+                    # always check to see if we should strip ansi here; if we don't handle this we
+                    # may raise auth failures for the wrong reason which would be confusing for
+                    # users
+                    if self._comms_ansi or b"\x1B" in output:
+                        output = strip_ansi(output=output)
+                    channel_match = re.search(pattern=prompt_pattern, string=output)
+                    if channel_match:
+                        self._isauthenticated = True
+                        break
+                    if b"password:" in output.lower():
+                        # if we see "password" we know auth failed (hopefully in all scenarios!)
+                        self.logger.critical(
+                            "Found `password:` in output, assuming password authentication failed"
+                        )
+                        break
+                    if output:
+                        self.logger.debug(
+                            f"Cannot determine if authenticated, \n\tRead: {repr(output)}"
+                        )
 
         if self._isauthenticated:
             return True
@@ -490,11 +499,10 @@ class SystemSSHTransport(Transport):
             N/A
 
         """
-        self.session_lock.acquire()
-        self.session.kill(0)
-        self.session.terminated = True
-        self.logger.debug(f"Channel to host {self.host} closed")
-        self.session_lock.release()
+        with self.session_lock:
+            self.session.kill(0)
+            self.session.terminated = True
+            self.logger.debug(f"Channel to host {self.host} closed")
 
     def isalive(self) -> bool:
         """
@@ -515,7 +523,7 @@ class SystemSSHTransport(Transport):
         return False
 
     @requires_open_session()
-    @operation_timeout("timeout_transport", "Timed out reading from transport")
+    @OperationTimeout("timeout_transport", "Timed out reading from transport")
     def read(self) -> bytes:
         """
         Read data from the channel
@@ -534,7 +542,7 @@ class SystemSSHTransport(Transport):
         return self.session.read(read_bytes)
 
     @requires_open_session()
-    @operation_timeout("timeout_transport", "Timed out writing to transport")
+    @OperationTimeout("timeout_transport", "Timed out writing to transport")
     def write(self, channel_input: str) -> None:
         """
         Write data to the channel
