@@ -18,7 +18,9 @@ def test_init(sync_generic_driver_conn):
 
 
 @pytest.mark.parametrize(
-    "strip_prompt", [True, False], ids=["strip_prompt", "no_strip_prompt"],
+    "strip_prompt",
+    [True, False],
+    ids=["strip_prompt", "no_strip_prompt"],
 )
 def test_send_command(sync_generic_driver_conn, strip_prompt):
     expected_raw = TEST_CASES["cisco_iosxe"]["test_send_input"]["raw_result"]
@@ -37,7 +39,9 @@ def test_send_command(sync_generic_driver_conn, strip_prompt):
 
 
 @pytest.mark.parametrize(
-    "strip_prompt", [True, False], ids=["strip_prompt", "no_strip_prompt"],
+    "strip_prompt",
+    [True, False],
+    ids=["strip_prompt", "no_strip_prompt"],
 )
 def test_send_commands(sync_generic_driver_conn, strip_prompt):
     expected_raw = TEST_CASES["cisco_iosxe"]["test_send_input"]["raw_result"]
@@ -55,7 +59,9 @@ def test_send_commands(sync_generic_driver_conn, strip_prompt):
 
 
 @pytest.mark.parametrize(
-    "strip_prompt", [True, False], ids=["strip_prompt", "no_strip_prompt"],
+    "strip_prompt",
+    [True, False],
+    ids=["strip_prompt", "no_strip_prompt"],
 )
 def test_send_commands_from_file(sync_generic_driver_conn, strip_prompt):
     expected_raw = TEST_CASES["cisco_iosxe"]["test_send_input"]["raw_result"]
