@@ -63,8 +63,14 @@ def test_build_open_cmd():
 @pytest.mark.skipif(sys.platform.startswith("win"), reason="systemssh not supported on windows")
 @pytest.mark.parametrize(
     "user_options",
-    [["oKexAlgorithms=+diffie-hellman-group1-sha1"], "oKexAlgorithms=+diffie-hellman-group1-sha1",],
-    ids=["user options list", "user options string",],
+    [
+        ["oKexAlgorithms=+diffie-hellman-group1-sha1"],
+        "oKexAlgorithms=+diffie-hellman-group1-sha1",
+    ],
+    ids=[
+        "user options list",
+        "user options string",
+    ],
 )
 def test_build_open_cmd_user_options(user_options):
     conn = SystemSSHTransport("localhost", transport_options={"open_cmd": user_options})
@@ -89,20 +95,42 @@ def test_build_open_cmd_user_options(user_options):
 @pytest.mark.parametrize(
     "eof_msg",
     [
-        (b"Host key verification failed", "Host key verification failed for host localhost",),
-        (b"Operation timed out", "Timed out connecting to host localhost",),
-        (b"Connection timed out", "Timed out connecting to host localhost",),
-        (b"No route to host", "No route to host localhost",),
-        (b"no matching key exchange found.", "No matching key exchange found for host localhost",),
+        (
+            b"Host key verification failed",
+            "Host key verification failed for host localhost",
+        ),
+        (
+            b"Operation timed out",
+            "Timed out connecting to host localhost",
+        ),
+        (
+            b"Connection timed out",
+            "Timed out connecting to host localhost",
+        ),
+        (
+            b"No route to host",
+            "No route to host localhost",
+        ),
+        (
+            b"no matching key exchange found.",
+            "No matching key exchange found for host localhost",
+        ),
         (
             b"no matching key exchange found. Their offer: diffie-hellman-group-exchange-sha1,diffie-hellman-group14-sha1",
             "No matching key exchange found for host localhost, their offer: diffie-hellman-group-exchange-sha1,diffie-hellman-group14-sha1",
         ),
-        (b"no matching cipher found", "No matching cipher found for host localhost",),
+        (
+            b"no matching cipher found",
+            "No matching cipher found for host localhost",
+        ),
         (
             b"no matching cipher found, their offer: aes128-cbc,aes256-cbc",
             "No matching cipher found for host localhost, their offer: aes128-cbc,aes256-cbc",
         ),
+        (
+            b"command-line: line 0: Bad configuration option: ciphers+",
+            "Bad SSH configuration option(s) for host localhost, bad option(s): ciphers+",
+        ),
         (
             b"WARNING: UNPROTECTED PRIVATE KEY FILE!",
             # note: empty quotes in the middle is where private key filename would be
@@ -123,6 +151,7 @@ def test_build_open_cmd_user_options(user_options):
         "no matching key exchange found key exchange",
         "no matching cipher",
         "no matching cipher found ciphers",
+        "bad configuration option",
         "unprotected key",
         "could not resolve host",
     ],
@@ -149,7 +178,9 @@ def test_set_timeout():
 
 @pytest.mark.skipif(sys.platform.startswith("win"), reason="systemssh not supported on windows")
 @pytest.mark.parametrize(
-    "method_name", ["read", "write"], ids=["read", "write"],
+    "method_name",
+    ["read", "write"],
+    ids=["read", "write"],
 )
 def test_requires_open(method_name):
     conn = SystemSSHTransport("localhost")
